@@ -51,7 +51,7 @@ def encrypt_body(data, secret_key):
     return json_body
 
 
-def decrypt_response(r):
+def decrypt_response(r, slience=False):
     try:
         res = r.json()
         if 'data' in res:
@@ -87,7 +87,7 @@ def ti_request(username, secret_key, method, url, data=None, slience=False):
     if not slience:
         print('Request Headers:', headers)
 
-    json_body = get_body(data, secret_key)
+    json_body = encrypt_body(data, secret_key)
 
     if not slience:
         print('Request Body:', json_body)
@@ -96,7 +96,7 @@ def ti_request(username, secret_key, method, url, data=None, slience=False):
     if not slience:
         print('Response:', r.status_code, r.text)
 
-    res = decrypt_response(r)
+    res = decrypt_response(r, slience)
 
     return res
 
